import React, { forwardRef, useState } from 'react';
import {
  Input,
  Box,
  Stack,
  Text,
  Flex,
} from '@chakra-ui/react';
import { useTranslation } from 'react-i18next';

import { CAR_COLORS } from './helper';

interface CarColorSelectProps {
  value?: string;
  onChange?: (event: React.ChangeEvent<HTMLInputElement>) => void;
  name?: string;
  isInvalid?: boolean;
}

export const CarColorSelect = forwardRef<HTMLInputElement, CarColorSelectProps>(
  function CarColorSelect(props) {
    const [customColor, setCustomColor] = useState('');
    const [isCustom, setIsCustom] = useState(false);

    const handleColorChange = (value: string) => {
      if (value === 'custom') {
        setIsCustom(true);
        return;
      }
      setIsCustom(false);
      props.onChange?.({
        target: { value },
      } as React.ChangeEvent<HTMLInputElement>);
    };

    const handleCustomColorChange = (e: React.ChangeEvent<HTMLInputElement>) => {
      const value = e.target.value;
      setCustomColor(value);
      props.onChange?.({
        target: { value },
      } as React.ChangeEvent<HTMLInputElement>);
    };

    const { t } = useTranslation('~', {
      keyPrefix: 'dry-wash.order-create.car-color-select',
    });

    const currentValue = isCustom ? 'custom' : props.value;

    return (
      <Stack spacing={4} width="100%">
        <Flex gap={3} wrap="nowrap" overflowX="auto" pb={2}>
          {CAR_COLORS.map(({ name, code }) => (
            <Box 
              key={name}
              flexShrink={0}
              as="button"
              type="button"
              onClick={() => handleColorChange(name)}
            >
              <Flex 
                align="center" 
                gap={2} 
                p={2}
                borderRadius="full"
                borderWidth="2px"
                borderColor={currentValue === name ? 'primary.500' : 'gray.200'}
                bg={currentValue === name ? 'primary.50' : 'white'}
                _hover={{ 
                  borderColor: 'primary.500',
                  bg: currentValue === name ? 'primary.50' : 'gray.50'
                }}
                minW={currentValue === name ? '120px' : 'auto'}
                h="48px"
                justify="center"
                transition="all 0.2s"
              >
                <Flex align="center" gap={2}>
                  <Box
                    w="32px"
                    h="32px"
                    borderRadius="full"
                    bg={code}
                    border="1px"
                    borderColor={currentValue === name ? 'primary.500' : 'gray.200'}
                    transition="all 0.2s"
                    boxShadow={currentValue === name ? 'sm' : 'none'}
                  />
                  {currentValue === name && (
                    <Text fontSize="xs" color="primary.700" fontWeight="medium">
                      {t(`colors.${name}`)}
                    </Text>
                  )}
                </Flex>
              </Flex>
            </Box>
          ))}
          <Box 
            flexShrink={0}
            as="button"
            type="button"
            onClick={() => handleColorChange('custom')}
          >
            <Flex 
              align="center" 
              gap={2}
              p={2}
              borderRadius="full"
              borderWidth="2px"
              borderColor={isCustom ? 'primary.500' : 'gray.200'}
              bg={isCustom ? 'primary.50' : 'white'}
              _hover={{ 
                borderColor: 'primary.500',
                bg: isCustom ? 'primary.50' : 'gray.50'
              }}
              minW={isCustom ? '200px' : 'auto'}
              h="48px"
              justify="center"
              transition="all 0.2s"
            >
              {isCustom ? (
                <Flex gap={2} align="center">
                  <Text fontSize="xs" color="primary.700" fontWeight="medium">
                    {t('custom-label')}
                  </Text>
                  <Input
                    size="sm"
                    width="120px"
                    value={customColor}
                    onChange={handleCustomColorChange}
                    placeholder={t('placeholder')}
                    onClick={(e) => e.stopPropagation()}
                    borderColor="primary.200"
                    _focus={{
                      borderColor: 'primary.500',
                      boxShadow: '0 0 0 1px var(--chakra-colors-primary-500)'
                    }}
                  />
                </Flex>
              ) : (
                <Flex align="center" gap={2}>
                  <Box
                    w="32px"
                    h="32px"
                    borderRadius="full"
                    bg="gray.100"
                    border="1px"
                    borderColor="gray.200"
                    transition="all 0.2s"
                  />
                  <Text fontSize="xs" color="gray.500">
                    {t('custom')}
                  </Text>
                </Flex>
              )}
            </Flex>
          </Box>
        </Flex>
      </Stack>
    );
  },
); 